#region Using directives
using UAManagedCore;
using OpcUa = UAManagedCore.OpcUa;
using QPlatform.HMIProject;
using QPlatform.NetLogic;
using QPlatform.System;
#endregion

public class NetworkConfigurator : BaseNetLogic
{
    public override void Start()
    {
        // Insert code to be executed when the user-defined logic is started
        var model = Project.Current.Get("Model");
        systemNode = model.Get<QPlatform.System.System>("Sistema1");

        if (systemNode == null)
            throw new CoreConfigurationException("SystemNode not found");
    }

    public override void Stop()
    {
        // Insert code to be executed when the user-defined logic is stopped
    }

    [ExportMethod]
    public void Refresh()
    {
        systemNode.Refresh();
    }

    [ExportMethod]
    public void EnableDHCP(string interfaceName, bool enabled)
    {
        foreach (var networkInterface in systemNode.NetworkInterfaces)
        {
            if (networkInterface.InterfaceName == interfaceName)
                networkInterface.DhcpEnabled = enabled;
        }
    }

    [ExportMethod]
    public void AddIpAddressToNetworkInterface(string interfaceName, string ipAddress, string mask)
    {
        foreach(var networkInterface in systemNode.NetworkInterfaces)
        {
            if (networkInterface.InterfaceName == interfaceName)
            {
                networkInterface.DhcpEnabled = false;
                networkInterface.IPAddress = ipAddress;
                networkInterface.IPAddressVariable.Mask = mask;
            }
        }
    }

    [ExportMethod]
    public void UpdateDNSAddressesToNetworkInterface(string interfaceName, string dns1, string dns2)
    {
        foreach (var networkInterface in systemNode.NetworkInterfaces)
        {
            if (networkInterface.InterfaceName == interfaceName)
            {
                networkInterface.DhcpEnabled = false;
                networkInterface.DNS1 = dns1;
                networkInterface.DNS2 = dns2;
            }
        }
    }

    [ExportMethod]
    public void UpdateDefaultGatewayToNetworkInterface(string interfaceName, string defaultGateway)
    {
        foreach (var networkInterface in systemNode.NetworkInterfaces)
        {
            if (networkInterface.InterfaceName == interfaceName)
            {
                networkInterface.DhcpEnabled = false;
                networkInterface.DefaultGateway = defaultGateway;
            }
        }
    }

    [ExportMethod]
    public void AddAdditionalIp(string interfaceName, string ipAddress, string mask)
    {
        foreach (var networkInterface in systemNode.NetworkInterfaces)
        {
            if (networkInterface.InterfaceName == interfaceName)
            {
                var additionalIPAddressVariable = InformationModel.MakeVariable<MaskedIPAddress>("MyAdditionalIP", OpcUa::DataTypes.String);
                additionalIPAddressVariable.SetValue(ipAddress);
                additionalIPAddressVariable.Mask = mask;
                networkInterface.AdditionalIPAddresses.Add(additionalIPAddressVariable);
            }
        }
    }

    private QPlatform.System.System systemNode;
}
